'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var PropTypes = require('prop-types');
var React = require('react');
var react = require('@emotion/react');
require('@babel/runtime/helpers/extends');
require('../icon/index.cjs');
var chevronIcon = require('../../icons/icons/chevronIcon.cjs');
var index = require('./thumbnails/index.cjs');
var style = require('./style.cjs');
var index$1 = require('../../constants/keyboardKeys/index.cjs');
require('../../constants/breakpoints/index.cjs');
require('../../constants/grid/index.cjs');
require('../../constants/mediaQueries/index.cjs');
require('../../constants/colors/primary.cjs');
require('../../constants/boxShadows/primary.cjs');
require('../../constants/colors/secondary.cjs');
require('../../constants/boxShadows/secondary.cjs');
var types = require('../../constants/themes/types.cjs');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var PropTypes__default = /*#__PURE__*/_interopDefaultLegacy(PropTypes);

var Accordion = _ref => {
  var {
    borderRadius = 'small',
    children,
    disabled = false,
    isOpen,
    noBorder = false,
    onClick: _onClick,
    rightAlignArrow = false,
    title
  } = _ref;
  var theme = react.useTheme();
  var [contentHeight, setContentHeight] = React.useState('0px');
  var contentRef = React.useRef(null);
  React.useEffect(() => {
    var nextHeight = isOpen && contentRef.current ? "".concat(contentRef.current.clientHeight, "px") : '0px';

    if (contentHeight !== nextHeight) {
      setContentHeight(nextHeight);
    }
  });

  var handleKeyDown = event => {
    if (!disabled && event.key === index$1.keyboardKeys.enter) {
      _onClick(event);
    }
  };

  return react.jsx(style["default"].AccordionBox, {
    isOpen: isOpen,
    noBorder: !!noBorder,
    disabled: !!disabled
  }, react.jsx(style["default"].TitleWrapper, {
    onClick: event => {
      if (!disabled) {
        _onClick(event);
      }
    },
    borderRadius: borderRadius,
    onKeyDown: handleKeyDown,
    disabled: !!disabled,
    role: "button",
    isOpen: isOpen,
    tabIndex: disabled ? -1 : 0,
    "aria-disabled": !!disabled,
    "aria-expanded": isOpen
  }, react.jsx(style["default"].Truncate, null, title), react.jsx(style["default"].ArrowWrapper, {
    rightAlign: !!rightAlignArrow
  }, react.jsx(chevronIcon["default"], {
    rotate: isOpen ? 90 : 0,
    fill: theme.COLORS.primary
  }))), react.jsx(style["default"].ExpansionWrapper, {
    contentHeight: contentHeight,
    "aria-disabled": !!disabled,
    "aria-hidden": !isOpen
  }, react.jsx("div", {
    ref: contentRef
  }, children)));
};
Accordion.Container = style["default"].Container;
Accordion.Content = style["default"].Content;
Accordion.Thumbnails = index.Thumbnails;
Accordion.Truncate = style["default"].Truncate;
Accordion.propTypes = {
  borderRadius: types.BORDER_RADIUS_PROP_TYPES,
  children: PropTypes__default["default"].node.isRequired,
  disabled: PropTypes__default["default"].bool,
  isOpen: PropTypes__default["default"].bool.isRequired,
  noBorder: PropTypes__default["default"].bool,
  onClick: PropTypes__default["default"].func.isRequired,
  rightAlignArrow: PropTypes__default["default"].bool,
  title: PropTypes__default["default"].node.isRequired
};

exports.Accordion = Accordion;
