import React from 'react';
import Container from '../../shared-components/container';
import { ThemeColors } from '../../../../constants';
import type { ButtonType } from '../../types';
export interface ButtonProps {
    buttonColor?: ThemeColors;
    /**
     * Determines the button's main style theme
     */
    buttonType?: ButtonType;
    /**
     * Node to be rendered inside the button. Recommended to be the button text
     */
    children: React.ReactNode;
    disabled?: boolean;
    /**
     * Icon to render in the button. Recommended to be a Radiance icon
     */
    icon?: React.ReactNode;
    /**
     * Adjusts the default button styles so that the button takes the full width of the container. Intended for mobile-use only.
     */
    isFullWidth?: boolean;
    /**
     * When loading, onClick function execution is disallowed
     */
    isLoading?: boolean;
    loading?: boolean;
    onClick?: (event: React.SyntheticEvent<HTMLButtonElement>) => void;
    /**
     * Color that will override existing text, icon, and loading colors for the button (except when disabled is true)
     */
    textColor?: ThemeColors;
    [key: string]: unknown;
}
interface Button extends React.FC<ButtonProps> {
    Container: typeof Container;
}
/**
 * Buttons can be used as a main call-to-action (CTA). Try to avoid using buttons of the same `buttonType` next to each other since we want to guide the user towards one option.
 *
 * `<Button.Container>` can be used to provide spacing between multiple buttons and behavior on various screen sizes. See Storybook for more details.
 *
 * We should generally try to use the default button color when possible. Only for special cases should we need to use a different button color.
 */
declare const Button: Button;
declare const ButtonComponent: Button;
export { ButtonComponent as Button };
//# sourceMappingURL=index.d.ts.map