import _extends from '@babel/runtime/helpers/extends';
import _objectWithoutProperties from '@babel/runtime/helpers/objectWithoutProperties';
import 'react';
import PropTypes from 'prop-types';
import { useTheme, jsx } from '@emotion/react';
import ButtonContainer from '../../shared-components/container/index.js';
import { ButtonContents, ButtonText } from '../../style.js';
import Style from './style.js';
import '../../../../constants/breakpoints/index.js';
import '../../../../constants/grid/index.js';
import '../../../../constants/mediaQueries/index.js';
import '../../../../constants/colors/primary.js';
import '../../../../constants/boxShadows/primary.js';
import '../../../../constants/colors/secondary.js';
import '../../../../constants/boxShadows/secondary.js';
import { COLORS_PROP_TYPES } from '../../../../constants/themes/types.js';

var _excluded = ["as", "buttonColor", "buttonType", "children", "disabled", "onClick", "textColor"];
var LinkButton = _ref => {
  var {
    as = 'a',
    buttonColor,
    buttonType = 'primary',
    children,
    disabled = false,
    onClick = () => undefined,
    textColor
  } = _ref,
      rest = _objectWithoutProperties(_ref, _excluded);

  var theme = useTheme();
  var ContainerTag = as;
  var buttonColorWithTheme = buttonColor !== null && buttonColor !== void 0 ? buttonColor : theme.COLORS.primary;
  return jsx(ContainerTag, _extends({
    css: Style.linkButtonStyles({
      disabled,
      buttonType,
      buttonColor: buttonColorWithTheme,
      textColor,
      theme
    }),
    disabled: disabled,
    onClick: !disabled ? onClick : () => false // eslint-disable-next-line react/jsx-props-no-spreading

  }, rest), jsx(ButtonContents, {
    isLoading: false,
    isFullWidth: false,
    hasIcon: false
  }, jsx(ButtonText, {
    isLoading: false,
    hasIcon: false
  }, children)));
};
LinkButton.Container = ButtonContainer;
LinkButton.propTypes = {
  as: PropTypes.oneOfType([PropTypes.string, PropTypes.elementType]),
  buttonColor: COLORS_PROP_TYPES,
  buttonType: PropTypes.oneOf(['primary', 'secondary', 'tertiary', 'quaternary']),
  children: PropTypes.node.isRequired,
  disabled: PropTypes.bool,
  onClick: PropTypes.func,
  textColor: COLORS_PROP_TYPES
};

export { LinkButton };
