import React from 'react';
import Style from './style';
export declare type CarouselType = 'primary' | 'secondary';
export interface CarouselProps {
    /**
     * Auto-advance the carousel cards
     */
    autoplay?: boolean;
    /**
     * Autoplay speed in milliseconds (ignored if autoplay is false)
     */
    autoplaySpeed?: number;
    /**
     * Align the arrows on the bottom right (dots are automatically hidden)
     */
    bottomRightAlignedArrows?: boolean;
    carouselType?: CarouselType;
    /**
     * Center the current card
     */
    centerMode?: boolean;
    /**
     * Array of `Carousel.Card`
     */
    children: Array<React.ReactNode>;
    hideArrows?: boolean;
    hideDots?: boolean;
    /**
     * Creates a carousel loop, i.e. if true you can go backwards from the beginning
     */
    infinite?: boolean;
    numCardsVisible: 1 | 2 | 3;
}
interface Carousel extends React.FC<CarouselProps> {
    Card: typeof Style.Card;
}
/**
 * Carousels should be used to provide valuable information or additional context on a page. One of the best examples of a Carousel is for product recommendations.
 *
 * The property `numCardsVisible` will define the width of the Carousel Container.
 *
 * An array of `Carousel.Card` must be used for the carousel content. It includes the base styles for the Card which may be extended as shown above.
 */
export declare const Carousel: Carousel;
export {};
//# sourceMappingURL=index.d.ts.map