'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var PropTypes = require('prop-types');
var react = require('@emotion/react');
var mobileDropdown = require('./mobileDropdown.cjs');
var desktopDropdown = require('./desktopDropdown.cjs');
var index = require('../../utils/isDefined/index.cjs');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var PropTypes__default = /*#__PURE__*/_interopDefaultLegacy(PropTypes);

var Dropdown = _ref => {
  var {
    borderRadius,
    id,
    onChange,
    onDropdownContainerFocus,
    options,
    optionsContainerMaxHeight = '250px',
    textAlign = 'left',
    value
  } = _ref;
  var theme = react.useTheme();
  var [isOpen, setIsOpen] = React.useState(false);
  var touchSupported = ('ontouchstart' in document.documentElement);
  var borderRadiusValue = borderRadius !== null && borderRadius !== void 0 ? borderRadius : theme.BORDER_RADIUS.small;

  var toggleDropdown = () => {
    setIsOpen(prevIsOpen => !prevIsOpen);
  };

  var closeDropdown = () => {
    setIsOpen(false);
  };

  var onMobileSelectChange = event => {
    var {
      target
    } = event;
    var {
      selectedIndex,
      selectedOptions
    } = target;
    var selectedOption = options[selectedIndex];

    if (selectedOptions.length) {
      onChange(selectedOption);
    }

    closeDropdown();
  };

  var onDesktopSelectChange = event => {
    var _currentTarget$getAtt;

    var {
      currentTarget
    } = event;

    if (currentTarget.hasAttribute('disabled')) {
      return;
    } // Next Value may be returned as null if the value of <li> is undefined. We want to cast to the real value of undefined


    var nextValue = (_currentTarget$getAtt = currentTarget.getAttribute('value')) !== null && _currentTarget$getAtt !== void 0 ? _currentTarget$getAtt : undefined;
    var selectedOption = options.find(option => {
      var {
        value: optionValue
      } = option; // This covers numbers and strings. <li> value is always returned as string. Falsy case covers undefined.

      return index.isDefined(optionValue) ? "".concat(optionValue) === nextValue : optionValue === nextValue;
    });

    if (selectedOption) {
      onChange(selectedOption);
    }

    closeDropdown();
  };

  var handleOnDropdownContainerFocus = event => {
    if (onDropdownContainerFocus) {
      onDropdownContainerFocus(event);
    }
  };

  if (touchSupported) {
    return react.jsx(mobileDropdown.MobileDropdown, {
      borderRadius: borderRadiusValue,
      id: id,
      onMobileSelectChange: onMobileSelectChange,
      onDropdownContainerFocus: handleOnDropdownContainerFocus,
      options: options,
      textAlign: textAlign,
      value: value
    });
  }

  var currentOption = options.find(option => option.value === value);
  return react.jsx(desktopDropdown.DesktopDropdown, {
    borderRadius: borderRadiusValue,
    closeDropdown: closeDropdown,
    currentOption: currentOption,
    id: id,
    isOpen: isOpen,
    onDesktopSelectChange: onDesktopSelectChange,
    onDropdownContainerFocus: handleOnDropdownContainerFocus,
    options: options,
    optionsContainerMaxHeight: optionsContainerMaxHeight,
    textAlign: textAlign,
    toggleDropdown: toggleDropdown,
    value: value
  });
};
Dropdown.propTypes = {
  borderRadius: PropTypes__default["default"].string,
  id: PropTypes__default["default"].string,
  onChange: PropTypes__default["default"].func.isRequired,
  options: PropTypes__default["default"].arrayOf(PropTypes__default["default"].shape({
    value: PropTypes__default["default"].oneOfType([PropTypes__default["default"].string, PropTypes__default["default"].number]),
    label: PropTypes__default["default"].string.isRequired,
    disabled: PropTypes__default["default"].bool
  }).isRequired).isRequired,
  optionsContainerMaxHeight: PropTypes__default["default"].string,
  textAlign: PropTypes__default["default"].oneOf(['left', 'center']),
  value: PropTypes__default["default"].oneOfType([PropTypes__default["default"].string, PropTypes__default["default"].number])
};

exports.Dropdown = Dropdown;
