import React from 'react';
import Style from './style';
import { MessagesTypes, MessageType } from '../verificationMessages';
export interface FieldProps {
    /**
     * Must be either `Field.Input` or `Field.Textarea`
     */
    children: JSX.Element;
    /**
     * Change the child input to `disabled` state
     */
    disabled?: boolean;
    /**
     * Hides the message icon at the rightmost part of the input
     */
    hideMessagesIcon?: boolean;
    /**
     * The hint to display below the field. It activates on focus
     */
    hintMessage?: string;
    /**
     * The field label
     */
    label?: string;
    /**
     * Must match the children id html attribute
     */
    labelFor?: string;
    /**
     * Object of key and React Node message pair. It also accepts an array of React Node as value
     */
    messages?: Record<string, MessageType>;
    messagesType?: MessagesTypes;
}
interface Field extends React.FC<FieldProps> {
    Input: typeof Style.Input;
    Textarea: typeof Style.Textarea;
}
/**
 * Field component uses VerificationMessages component internally along with extra styling for the input.
 *
 * If you don't need validation, label or hint message; you can use `Field.Input` or `Field.Textarea` directly without the `Field` wrapper.
 */
export declare const Field: Field;
export {};
//# sourceMappingURL=index.d.ts.map