import React from 'react';
import Style from './style';
export interface ImmersiveModalProps {
    /**
     * Modal body
     */
    children: React.ReactNode;
    /**
     * Recommended for buttons. This content is render at the bottom of the modal
     */
    footerContent?: React.ReactNode;
    /**
     * Image that will render at the top of the modal
     */
    headerImage?: React.ReactNode;
    /**
     * Function to close the modal
     */
    onClose: () => void;
    /**
     * The title of the modal
     */
    title?: string | JSX.Element;
    [key: string]: unknown;
}
interface ImmersiveModal extends React.FC<ImmersiveModalProps> {
    Paragraph: typeof Style.Paragraph;
}
/**
 * It is used to provide a layer on top of a page when we need to present more content and actions to patients.
 *
 * It should not be used as a step to add friction / confirm an action, use `Dialog Modal` instead.
 *
 * They are closable if clicked outside of container.
 *
 * Immersive modals always include the close button.
 *
 * Modals can contain a header image that is 240px tall (264px on desktop). Images should not contain rounded corners.
 *
 * `ImmersiveModal.Paragraph` subcomponent may be used to add some margin to the paragraphs inside the modal body.
 */
export declare const ImmersiveModal: ImmersiveModal;
export {};
//# sourceMappingURL=index.d.ts.map