import { useRef, useEffect } from 'react';
import PropTypes from 'prop-types';
import { jsx } from '@emotion/react';

var OffClickWrapper = _ref => {
  var {
    children,
    className,
    onOffClick
  } = _ref;
  var containerRef = useRef(null);

  var handleKeyPress = event => {
    if (event.key === 'Escape') {
      onOffClick(event);
    }
  };

  var handleOffClick = event => {
    var node = containerRef.current;

    if (!node) {
      return;
    }

    if (node.contains(event.target)) {
      return;
    }

    onOffClick(event);
  };

  useEffect(() => {
    document.addEventListener('click', handleOffClick, {
      capture: true
    });
    document.addEventListener('keydown', handleKeyPress, {
      capture: true
    });
    return () => {
      document.removeEventListener('click', handleOffClick, false);
      document.removeEventListener('keydown', handleKeyPress, false);
    };
  }, []);
  return jsx("div", {
    ref: containerRef,
    className: className
  }, children);
};
OffClickWrapper.propTypes = {
  children: PropTypes.node.isRequired,
  className: PropTypes.string,
  onOffClick: PropTypes.func.isRequired
};

export { OffClickWrapper };
