import React from 'react';
import { ThemeType } from '../../constants';
export interface OptionButtonProps {
    borderRadius?: keyof ThemeType['BORDER_RADIUS'];
    buttonType?: 'primary' | 'secondary';
    /**
     * Show custom icon in the unselected state
     */
    icon?: React.ReactNode;
    image?: string;
    onClick: () => void;
    optionType: 'radio' | 'checkbox';
    selected?: boolean;
    subtext?: React.ReactNode;
    text: string;
    textContainerHeight?: number;
    withImageBackground?: boolean;
    [key: string]: unknown;
}
export interface OptionButtonNotClickableProps extends Pick<OptionButtonProps, 'borderRadius' | 'icon' | 'optionType' | 'subtext' | 'text' | 'image'> {
    icon: JSX.Element;
}
export declare type OptionButtonContentProps = Pick<OptionButtonProps, 'buttonType' | 'icon' | 'optionType' | 'selected' | 'subtext' | 'text' | 'image' | 'borderRadius' | 'textContainerHeight'>;
export declare type OptionButtonIconProps = Pick<OptionButtonProps, 'buttonType' | 'icon' | 'optionType' | 'selected' | 'withImageBackground'>;
export declare const OptionButtonIcon: React.FC<OptionButtonIconProps>;
interface OptionButton extends React.FC<OptionButtonProps> {
    NotClickable: typeof OptionButtonNotClickable;
    height?: string;
}
/**
 * The `OptionButton` is used within a focused flow (such as the signup page)
 * to provide more context and attention to each selection option.
 *
 * There is also an OptionButton.Container sub-component to be used when we
 * want to use the OptionButton as a purely presentational component rather
 * than a functional button associated with form inputs
 */
export declare const OptionButton: OptionButton;
/**
 * A presentational component to match the display of an OptionButton with an icon
 */
export declare const OptionButtonNotClickable: React.FC<OptionButtonNotClickableProps>;
export {};
//# sourceMappingURL=index.d.ts.map